from setuptools import setup

setup(name = 'hepo_probability',
      version = '0.1',
      description = 'Gaussian and Binomial distributions',
      packages = ['hepo_probability_gaussian_binomial'],
      author = 'Eddie Palomino',
      author_email = 'palomino.ochoah@gmail.com',
    zip_safe=False)
